@@ -29,6 +29,7 @@ $(function() {
     let buttons_activated = false;
     let counter_of_trees = 0;
     let found = null;
+    let context_id;
 
     $("#logo-main").offset({left: maxWidth/2 - $("#logo-main").width()/2, top: maxHeight/2 - $("#logo-main").height()/2});
 
@@ -330,8 +331,8 @@ $(function() {
     }
 
     function tests(data) {
-        $("#info-modal-label").text("Tests clicked!")
-        $("#info-modal-body").text("Tests are getting calculated!")
+        $("#info-modal-label").text("Tree topoplogy tests started!")
+        $("#info-modal-body").text("Tree toplogy tests are being performed now. A progress bar will be added soon!")
         $("#info-modal").modal("show");
         $.post("tests", data, function(data) {
             data = JSON.parse(data);
@@ -576,7 +577,12 @@ $(function() {
         let nameText;
 
         function outgroup() {
-            if (!(typeof clickedPath === "undefined" || (typeof clickedPath === "object" && !clickedPath))) {
+             if (context_id != null) {
+                load("get", {
+                    'id': context_id
+                });
+                context_id = null;
+            } else if (!(typeof clickedPath === "undefined" || (typeof clickedPath === "object" && !clickedPath))) {
                 if (counter_of_trees == number_of_trees) {
                     load("get", {
                         'id': clickedPath.attr("data-id")
@@ -1027,10 +1033,18 @@ $(function() {
                 $("#undo-button").click(function (event) {
                     undo();
                 });
+                $("#context-undo").click(function (event) {
+                    $("#context-menu").removeClass("visible");
+                    undo();
+                });
 
                 $("#redo-button").click(function (event) {
                     redo();
                 });
+                $("#context-redo").click(function (event) {
+                    $("#context-menu").removeClass("visible");
+                    redo();
+                });
 
                 $("#save-button").click(function (event) {
                     $("#snapshot-label").val("");
@@ -1039,6 +1053,14 @@ $(function() {
                         $("#snapshot-label").focus();
                     });
                 });
+                $("#context-save").click(function (event) {
+                    $("#context-menu").removeClass("visible");
+                    $("#snapshot-label").val("");
+                    $("#save-modal").modal("show");
+                    $("#save-modal").on("shown.bs.modal", function () {
+                        $("#snapshot-label").focus();
+                    });
+                });
 
                 $("#save-modal-button").click(function (event) {
                     save();
@@ -1048,10 +1070,18 @@ $(function() {
                 $("#zoom-in-button").click(function (event) {
                     setTransform("scale", getTransform("scale") + step, getTransform("x"), getTransform("y"));
                 });
+                $("#context-zoom-in").click(function (event) {
+                    $("#context-menu").removeClass("visible");
+                    setTransform("scale", getTransform("scale") + step, getTransform("x"), getTransform("y"));
+                });
 
                 $("#zoom-out-button").click(function (event) {
                     setTransform("scale", getTransform("scale") - step, getTransform("x"), getTransform("y"));
                 });
+                $("#context-zoom-out").click(function (event) {
+                    $("#context-menu").removeClass("visible");
+                    setTransform("scale", getTransform("scale") - step, getTransform("x"), getTransform("y"));
+                });
 
                 $("#search-button").click(function (event) {
                     search($("#search-text").val());
@@ -1066,6 +1096,10 @@ $(function() {
                 $("#outgroup-button").click(function (event) {
                     outgroup();
                 });
+                $("#context-outgroup").click(function (event) {
+                    $("#context-menu").removeClass("visible");
+                    outgroup("id");
+                });
                 buttons_activated = true;
             }
         }
@@ -1239,4 +1273,94 @@ $(function() {
 
     $("#btn2").click();
 
+    $("#alignment-file-button").on("click", function () {
+        $("#alignment-file").trigger("click");
+    });
+    $("#alignment-file:file").change(function (){
+        $("#alignment-file-button").html('<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-file-earmark-check" viewBox="0 0 16 16"><path d="M10.854 7.854a.5.5 0 0 0-.708-.708L7.5 9.793 6.354 8.646a.5.5 0 1 0-.708.708l1.5 1.5a.5.5 0 0 0 .708 0l3-3z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/></svg>');
+        $('label[for="alignment-file-button"]').html($(this)[0].files[0].name);
+
+        let autoReader = new FileReader();
+        autoReader.onload = function(data) {
+            text = atob(data.target.result.split("base64,")[1]);
+            if ((text.match(/[ACGT]/g) || []).length > text.length / 2) {
+                $("#dna").trigger("click");
+            } else {
+                $("#protein").trigger("click");
+            }
+            optionsJSON = {
+                "enable-lengths": $("#enable-lengths")[0].checked
+            }
+            if (dnaProtein == "dna") {
+                optionsJSON["dna-protein"] = "dna";
+                optionsJSON["dna-bsr"] = $("#selectBSR").val();
+                optionsJSON["dna-bf"] = $("#selectBF").val();
+                optionsJSON["dna-rhas"] = $("#selectDNARHAS").val();
+            } else if (dnaProtein == "protein") {
+                optionsJSON["dna-protein"] = "protein";
+                optionsJSON["protein-aaerm"] = $("#selectAAERM").val();
+                optionsJSON["protein-pmm"] = $("#selectPMM").val();
+                optionsJSON["protein-aaf"] = $("#selectAAF").val();
+                optionsJSON["protein-rhas"] = $("#selectAARHAS").val();
+            }
+            options(optionsJSON);
+        }
+        autoReader.readAsDataURL($(this)[0].files[0]);
+    });
+
+    $("#tree-file-button").on("click", function () {
+        $("#tree-file").trigger("click");
+    });
+    $("#tree-file:file").change(function (){
+        $("#tree-file-button").html('<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-file-earmark-check" viewBox="0 0 16 16"><path d="M10.854 7.854a.5.5 0 0 0-.708-.708L7.5 9.793 6.354 8.646a.5.5 0 1 0-.708.708l1.5 1.5a.5.5 0 0 0 .708 0l3-3z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/></svg>');
+        $('label[for="tree-file-button"]').html($(this)[0].files[0].name);
+        var path = (window.URL || window.webkitURL).createObjectURL($(this)[0].files[0]);
+        console.log('path', path);
+    });
+
+    $("#working-directory-button").on("click", function () {
+        $("#working-directory").trigger("click");
+    });
+    $("#working-directory:file").change(function (){
+        $("#working-directory-button").html('<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-folder-check" viewBox="0 0 16 16"><path d="m.5 3 .04.87a1.99 1.99 0 0 0-.342 1.311l.637 7A2 2 0 0 0 2.826 14H9v-1H2.826a1 1 0 0 1-.995-.91l-.637-7A1 1 0 0 1 2.19 4h11.62a1 1 0 0 1 .996 1.09L14.54 8h1.005l.256-2.819A2 2 0 0 0 13.81 3H9.828a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 6.172 1H2.5a2 2 0 0 0-2 2zm5.672-1a1 1 0 0 1 .707.293L7.586 3H2.19c-.24 0-.47.042-.683.12L1.5 2.98a1 1 0 0 1 1-.98h3.672z"/><path d="M15.854 10.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.707 0l-1.5-1.5a.5.5 0 0 1 .707-.708l1.146 1.147 2.646-2.647a.5.5 0 0 1 .708 0z"/></svg>');
+        $('label[for="working-directory-button"]').html($(this)[0].files[0].webkitRelativePath.split("/")[0]);
+        console.log($(this));
+        var path = (window.URL || window.webkitURL).createObjectURL($(this)[0].files[0]);
+        console.log('path', path);
+    });
+
+    function normalizePosition(mouseX, mouseY) {
+        let normalizedX = mouseX;
+        let normalizedY = mouseY;
+        if (mouseX + $("#context-menu").outerWidth() > $("#mainDiv").outerWidth()) {
+            normalizedX = $("#mainDiv").outerWidth() - $("#context-menu").outerWidth();
+        }
+        if (mouseY + $("#context-menu").outerHeight() > $("#mainDiv").outerHeight()) {
+            normalizedY = $("#mainDiv").outerHeight() - $("#context-menu").outerHeight();
+        }
+        return {normalizedX, normalizedY};
+    }
+
+    $("#mainDiv").contextmenu(function (event) {
+        if (event.target.tagName == "line" || event.target.tagName == "svg" || event.target.tagName == "path") {
+            event.preventDefault();
+            const {clientX: mouseX, clientY: mouseY} = event;
+            const {normalizedX, normalizedY} = normalizePosition(mouseX, mouseY);
+            $("#context-menu").css({top: normalizedY, left: normalizedX});
+            $("#context-menu").addClass("visible");
+            if (event.target.tagName == "path") {
+                $("#context-outgroup").show();
+                context_id = $(event.target).data("id");
+            } else {
+                $("#context-outgroup").hide();
+            }
+        }
+    });
+
+    $("#mainDiv").mousedown(function (event) {
+        if (event.target.offsetParent != $("#context-menu")) {
+            $("#context-menu").removeClass("visible");
+        }
+    });
+
 });
\ No newline at end of file
